@@ -190,10 +190,10 @@ def check_daemon(aname, uname = None):
    if uname:
       check_vuser(uname, aname)
       pcmd = "ps -u {} -f | grep {} | grep ' 1 '".format(uname, aname)
-      mp = "^\s*{}\s+(\d+)\s+1\s+".format(uname)
+      mp = r"^\s*{}\s+(\d+)\s+1\s+".format(uname)
    else:
       pcmd = "ps -C {} -f | grep ' 1 '".format(aname)
-      mp = "^\s*\w+\s+(\d+)\s+1\s+"
+      mp = r"^\s*\w+\s+(\d+)\s+1\s+"
       
    buf = PgLOG.pgsystem(pcmd, PgLOG.LOGWRN, 20+1024)
    if buf:
@@ -220,10 +220,10 @@ def check_application(aname, uname = None, sargv = None):
    if uname:
       check_vuser(uname, aname)
       pcmd = "ps -u {} -f | grep {} | grep -v ' grep '".format(uname, aname)
-      mp = "^\s*{}\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(uname, aname)
+      mp = r"^\s*{}\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(uname, aname)
    else:
       pcmd = "ps -C {} -f".format(aname)
-      mp = "^\s*\w+\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(aname)
+      mp = r"^\s*\w+\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(aname)
 
    buf = PgLOG.pgsystem(pcmd, PgLOG.LOGWRN, 20+1024)
    if not buf: return 0
@@ -293,10 +293,10 @@ def check_multiple_application(aname, uname = None, sargv = None):
    if uname:
       check_vuser(uname, aname)
       pcmd = "ps -u {} -f | grep {} | grep -v ' grep '".format(uname, aname)
-      mp = "^\s*{}\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(uname, aname)
+      mp = r"^\s*{}\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(uname, aname)
    else:
       pcmd = "ps -C {} -f".format(aname)
-      mp = "^\s*\w+\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(aname)
+      mp = r"^\s*\w+\s+(\d+)\s+(\d+)\s+.*{}\S*\s+(.*)$".format(aname)
 
    buf = PgLOG.pgsystem(pcmd, PgLOG.LOGWRN, 20+1024)
    if not buf: return 0
@@ -1089,7 +1089,7 @@ def record_background(bcmd, logact = PgLOG.LOGWRN):
       aname = bcmd
 
    mp = r"^\s*(\S+)\s+(\d+)\s+1\s+.*{}(.*)$".format(aname)
-   pc = "ps -u {},{} -f | grep ' 1 ' | grep {}".format(PgLOG.PGLOG['CURUID'], PgLOG.PGLOG['RDAUSER'], aname)
+   pc = "ps -u {},{} -f | grep ' 1 ' | grep {}".format(PgLOG.PGLOG['CURUID'], PgLOG.PGLOG['GDEXUSER'], aname)
    for i in range(2):
       buf = PgLOG.pgsystem(pc, logact, 20+1024)
       if buf:
@@ -1100,7 +1100,7 @@ def record_background(bcmd, logact = PgLOG.LOGWRN):
             (uid, sbid, acmd) = ms.groups()
             bid = int(sbid)
             if bid in CBIDS: return -1
-            if uid == PgLOG.PGLOG['RDAUSER']:
+            if uid == PgLOG.PGLOG['GDEXUSER']:
                acmd = re.sub(r'^\.(pl|py)\s+', '', acmd, 1)
             if re.match(r'^{}{}'.format(aname, acmd), bcmd): continue
             CBIDS[bid] = bcmd
